import {
  axisLeft,
  axisBottom,
  scaleLinear,
  extent,
  scaleTime,
  line,
  curveBasis,
  timeFormat
} from 'd3'; 

export const lineChart = (selection, props) => {
  
    const {
      data,
      colorScale,
      width,
      height,
      margin,
      title,
      xValue,
      xAxisLabel,
      yValue,
      yAxisLabel,
      innerWidth,
      innerHeight,
      yValue2,
      yValue3,
      yValue4,
      yValue5,
      yValue6,
      yValue7,
      yValue8,
      yValue9
  } = props;
  
  //console.log(title);
  

  
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g
    .enter().append('g')
      .attr('class', 'container');
  gEnter
    .merge(g)
      .attr('transform',
        `translate(${margin.left},${margin.top})`
      )
  
  gEnter.append('text')
    .merge(g.select('.title'))
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue2))
    .range([innerHeight, 0])
    .nice();
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15)
    .tickFormat(timeFormat('%b'));
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
    .append('g')
      .attr('class', 'y-axis');
  
  yAxisG.merge(yAxisGEnter)
      .call(yAxis)
    .selectAll('.domain').remove();

  yAxisGEnter.append('text')
    .attr('class', 'axis-label')
    .attr('y', -73)
    .attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle')
  .merge(yAxisG.select('.axis-label'))
    .attr('x', -innerHeight / 2)
    .text(yAxisLabel);
  
    
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
    .append('g')
      .attr('class', 'x-axis');
  
  xAxisG
    .merge(xAxisGEnter)
      .attr('transform', `translate(0,${innerHeight})`)
      .call(xAxis)
      .selectAll('domain').remove();
  
  xAxisGEnter.append('text')
    .attr('class', 'axis-label')
    .attr('y', 75)
    .attr('fill', 'black')
  .merge(xAxisG.select('.axis-label'))
    .attr('x', innerWidth / 2)
    .text(xAxisLabel);
  
  

//////////////////line stuff

  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
    .curve(curveBasis);

    

  let dataline = gEnter
    .append('path')
      .attr('class', 'dataline')
    .merge(g.select('dataline'))
      .attr('d', lineGenerator(data));
///// 
  const lineGenerator2 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue2(d)))
    .curve(curveBasis);

  //console.log(yValue2);
  let dataline2 = gEnter
    .append('path')
      .attr('class', 'dataline2')
    .merge(g.select('dataline2'))
      .attr('d', lineGenerator2(data));
////  
  const lineGenerator3 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue3(d)))
    .curve(curveBasis);

    
  //console.log(yValue3);
  let dataline3 = gEnter
    .append('path')
      .attr('class', 'dataline3')
    .merge(g.select('dataline3'))
      .attr('d', lineGenerator3(data));
///// 
  const lineGenerator4 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue4(d)))
    .curve(curveBasis);

  //console.log(yValue4);
  let dataline4 = gEnter
    .append('path')
      .attr('class', 'dataline4')
    .merge(g.select('dataline4'))
      .attr('d', lineGenerator4(data));
  
////  
  const lineGenerator5 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue5(d)))
    .curve(curveBasis);


  let dataline5 = gEnter
    .append('path')
      .attr('class', 'dataline5')
    .merge(g.select('dataline5'))
      .attr('d', lineGenerator5(data));
///// 
  const lineGenerator6 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue6(d)))
    .curve(curveBasis);

  //console.log(yValue6);
  let dataline6 = gEnter
    .append('path')
      .attr('class', 'dataline6')
    .merge(g.select('dataline6'))
      .attr('d', lineGenerator6(data));
  
////  
  const lineGenerator7 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue7(d)))
    .curve(curveBasis);


  let dataline7 = gEnter
    .append('path')
      .attr('class', 'dataline7')
    .merge(g.select('dataline7'))
      .attr('d', lineGenerator7(data));
///// 
  const lineGenerator8 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue8(d)))
    .curve(curveBasis);

  //console.log(yValue8);
  let dataline8 = gEnter
    .append('path')
      .attr('class', 'dataline8')
    .merge(g.select('dataline8'))
      .attr('d', lineGenerator8(data));
///// 
  const lineGenerator9 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue9(d)))
    .defined(d => isNaN(d))
    .curve(curveBasis);

  //console.log(yValue9);
  let dataline9 = gEnter
    .append('path')
      .attr('class', 'dataline9')
    .merge(g.select('dataline9'))
      .attr('d', lineGenerator9(data));
  
}